@@ -34,8 +34,8 @@
 #' @examples
 #'
 #' # Example 1: predictive distribution from uniform prior.
-#' bm <- mixbeta(c(1,1,1))
-#' bmPred <- preddist(bm, n=10)
+#' bm <- mixbeta(c(1, 1, 1))
+#' bmPred <- preddist(bm, n = 10)
 #' # predictive proabilities and cumulative predictive probabilities
 #' x <- 0:10
 #' d <- dmix(bmPred, x)
@@ -45,32 +45,32 @@
 #' names(cd) <- x
 #' barplot(cd)
 #' # median
-#' mdn <- qmix(bmPred,0.5)
+#' mdn <- qmix(bmPred, 0.5)
 #' mdn
 #'
 #' # Example 2: 2-comp Beta mixture
 #'
-#' bm <- mixbeta( inf=c(0.8,15,50),rob=c(0.2,1,1))
+#' bm <- mixbeta(inf = c(0.8, 15, 50), rob = c(0.2, 1, 1))
 #' plot(bm)
-#' bmPred <- preddist(bm,n=10)
+#' bmPred <- preddist(bm, n = 10)
 #' plot(bmPred)
-#' mdn <- qmix(bmPred,0.5)
+#' mdn <- qmix(bmPred, 0.5)
 #' mdn
-#' d <- dmix(bmPred,x=0:10)
+#' d <- dmix(bmPred, x = 0:10)
 #' \donttest{
 #' n.sim <- 100000
-#' r <-  rmix(bmPred,n.sim)
+#' r <- rmix(bmPred, n.sim)
 #' d
-#' table(r)/n.sim
+#' table(r) / n.sim
 #' }
 #'
 #' # Example 3: 3-comp Normal mixture
 #'
-#' m3 <- mixnorm( c(0.50,-0.2,0.1),c(0.25,0,0.2), c(0.25,0,0.5), sigma=10)
+#' m3 <- mixnorm(c(0.50, -0.2, 0.1), c(0.25, 0, 0.2), c(0.25, 0, 0.5), sigma = 10)
 #' print(m3)
 #' summary(m3)
 #' plot(m3)
-#' predm3 <- preddist(m3,n=2)
+#' predm3 <- preddist(m3, n = 2)
 #' plot(predm3)
 #' print(predm3)
 #' summary(predm3)
@@ -83,10 +83,10 @@ preddist.default <- function(mix, ...) stop("Unknown distribution")
 #' @describeIn preddist Obtain the matching predictive distribution
 #'     for a beta distribution, the BetaBinomial.
 #' @export
-preddist.betaMix <- function(mix, n=1, ...) {
-    attr(mix, "n") <- n
-    class(mix) <- c("betaBinomialMix", "mix")
-    mix
+preddist.betaMix <- function(mix, n = 1, ...) {
+  attr(mix, "n") <- n
+  class(mix) <- c("betaBinomialMix", "mix")
+  mix
 }
 
 #' @describeIn preddist Obtain the matching predictive distribution
@@ -97,35 +97,36 @@ preddist.betaMix <- function(mix, n=1, ...) {
 #'     unspecified, the default reference scale of the mixture is
 #'     assumed.
 #' @export
-preddist.normMix <- function(mix, n=1, sigma, ...) {
-    if(missing(sigma)) {
-        sigma <- RBesT::sigma(mix)
-        message("Using default mixture reference scale ", sigma)
-    }
-    assert_number(sigma, lower=0)
-    sigma_ref <- sigma
-    ## note: this is effectivley a hierarchical model as we give the
-    ## distribution of the sum of n variables which have exactly the
-    ## same mean (which is sampled from the normal)
-    ## old: sum over y_i
-    ##mix[2,] <- mix[2,] * n
-    ##mix[3,] <- sqrt(mix[3,]^2 * n^2 + tau^2 * n )
-    ## now: predictive for \bar{y}_n, the mean
-    mix[3,] <- sqrt(mix[3,]^2  + sigma_ref^2/n )
-    class(mix) <- c("normMix", "mix")
-    mix
+preddist.normMix <- function(mix, n = 1, sigma, ...) {
+  if (missing(sigma)) {
+    sigma <- RBesT::sigma(mix)
+    message("Using default mixture reference scale ", sigma)
+  }
+  assert_number(sigma, lower = 0)
+  sigma_ref <- sigma
+  ## note: this is effectivley a hierarchical model as we give the
+  ## distribution of the sum of n variables which have exactly the
+  ## same mean (which is sampled from the normal)
+  ## old: sum over y_i
+  ## mix[2,] <- mix[2,] * n
+  ## mix[3,] <- sqrt(mix[3,]^2 * n^2 + tau^2 * n )
+  ## now: predictive for \bar{y}_n, the mean
+  mix[3, ] <- sqrt(mix[3, ]^2 + sigma_ref^2 / n)
+  class(mix) <- c("normMix", "mix")
+  mix
 }
 
 #' @describeIn preddist Obtain the matching predictive distribution
 #'     for a Gamma. Only Poisson likelihoods are supported.
 #' @export
-preddist.gammaMix <- function(mix, n=1, ...) {
-    assert_set_equal(likelihood(mix), "poisson")
-    attr(mix, "n") <- n
-    class(mix) <- c(switch(likelihood(mix),
-                           poisson="gammaPoissonMix",
-                           exp="gammaExpMix"), "mix")
-    mix
+preddist.gammaMix <- function(mix, n = 1, ...) {
+  assert_set_equal(likelihood(mix), "poisson")
+  attr(mix, "n") <- n
+  class(mix) <- c(switch(likelihood(mix),
+    poisson = "gammaPoissonMix",
+    exp = "gammaExpMix"
+  ), "mix")
+  mix
 }
 
 #' @describeIn preddist Multivariate normal mixtures predictive
